#!/bin/bash

exec > BUILD_SDL2.log 2>&1

BUILD_FROM_MERCURY="0"

LIBDIRS="SDL2
         SDL2_image
         SDL2_mixer_mod
         SDL2_mixer_mp3
         SDL2_mixer
         SDL2_net"

SDL_DIR_CLEAN="SDL2.clean"
SDL_DIR_BUILD="SDL2.build"

SEP1="=========="
SEP2="----------"
SEP1LINE="$SEP1$SEP1$SEP1$SEP1$SEP1$SEP1$SEP1$SEP1"
SEP2LINE="$SEP2$SEP2$SEP2$SEP2$SEP2$SEP2$SEP2$SEP2"

echo "$SEP1LINE"
echo "building SDL2 libraries"
echo "$SEP1LINE"
echo ""

if [ `uname` = "Darwin" ]; then
    PLATFORM="mac"
else
    PLATFORM="linux"
fi

rm -rf "$SDL_DIR_BUILD"
cp -a "$SDL_DIR_CLEAN" "$SDL_DIR_BUILD"

cd "$SDL_DIR_BUILD"

for i in $LIBDIRS; do

    echo "$SEP2LINE"
    echo "building library '$i'"
    echo "$SEP2LINE"
    echo ""

    cd "$i"

    if [ "$BUILD_FROM_MERCURY" != "0" ]; then
        if [ -x "autogen.sh" ]; then
	    ./autogen.sh || exit
        fi
    fi

    if [ "$PLATFORM" = "mac" ]; then
        # export CC=clang

        MAC_TARGET_VERSION_OLD="10.5"
        MAC_TARGET_VERSION_MIN="10.7"

        EXTRA_FLAGS_OLD="-mmacosx-version-min=$MAC_TARGET_VERSION_OLD"
        EXTRA_FLAGS_ALL="-mmacosx-version-min=$MAC_TARGET_VERSION_MIN"
        EXTRA_FLAGS_CXX="-stdlib=libc++"

        export MACOSX_DEPLOYMENT_TARGET="$MAC_TARGET_VERSION_MIN"

        export CFLAGS=$EXTRA_FLAGS_ALL
        export LDFLAGS=$EXTRA_FLAGS_ALL

        export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig

        if [ "$i" = "SDL2_mixer_mod" ]; then
            cp -a configure configure.orig
            cat configure.orig | sed -e "s/ $EXTRA_FLAGS_OLD//" > configure

            export CXXFLAGS="$EXTRA_FLAGS_ALL $EXTRA_FLAGS_CXX"
            export LDFLAGS="$EXTRA_FLAGS_ALL $EXTRA_FLAGS_CXX"
        fi
    fi

    ./configure		|| exit
    make		|| exit
    sudo make install	|| exit

    cd -

    echo ""
done

echo "Done."
