#!/bin/bash

LIB_PATH_1="/usr/local/lib"
LIB_PATH_2="/lib"

LIB_TARGET_DIR="lib"

CP="cp -aL"

SET_LIB_NAME="install_name_tool -id"
SET_DEP_NAME="install_name_tool -change"

SDL_DIR_BUILD="SDL2.build"

if [ `uname` = "Darwin" ]; then
    PLATFORM="mac"

    LIBS="libSDL2.dylib
          libSDL2_image.dylib
          libSDL2_mixer.dylib
          libSDL2_net.dylib
          libmodplug.dylib
          libmpg123.dylib"
else
    PLATFORM="linux"

    LIBS="libSDL2-2.0.so.0
          libSDL2_image-2.0.so.0
          libSDL2_mixer-2.0.so.0
          libSDL2_net-2.0.so.0
          libmodplug.so.1
          libmpg123.so.0
          libpng12.so.0
          libz.so.1"
fi

echo "Copying libraries ..."

for i in $LIBS; do
    echo "- copying '$i' ..."

    if [ -f "$LIB_PATH_1/$i" ]; then
	$CP "$LIB_PATH_1/$i" "$LIB_TARGET_DIR"
    elif [ -f "$LIB_PATH_2/$i" ]; then
	$CP "$LIB_PATH_2/$i" "$LIB_TARGET_DIR"
    else
	echo "Error: cannot find library file '$i'!"

	exit 10
    fi

    if [ "$PLATFORM" = "mac" ]; then
	strip -x "$LIB_TARGET_DIR/$i"
    fi

    chmod +x "$LIB_TARGET_DIR/$i"
done

echo "Preparing libraries ..."

if [ "$PLATFORM" = "mac" ]; then
    LIB_PATH_OLD="/usr/local/lib"
    # LIB_PATH_NEW="@executable_path/lib"
    LIB_PATH_NEW="@executable_path/../Frameworks"

    for i in $LIBS; do
	echo "- preparing '$i' ..."

	LIB="$LIB_TARGET_DIR/$i"

	DEP_LIBS=`otool -L "$LIB" | grep "$LIB_PATH_OLD" | awk '{ print $1 }'`

	for j in $DEP_LIBS; do
	    LIB_NAME_OLD="$j"
	    LIB_NAME_NEW=`echo "$LIB_NAME_OLD"			\
		| sed -e "s/[-\.].*$/.dylib/"			\
		| sed -e "s%$LIB_PATH_OLD%$LIB_PATH_NEW%"`

	    LIB_BASENAME_NEW=`basename "$LIB_NAME_NEW"`

	    # echo "  + '$LIB_NAME_OLD' => '$LIB_NAME_NEW'"

	    if [ "$i" = "$LIB_BASENAME_NEW" ]; then
		$SET_LIB_NAME                 "$LIB_NAME_NEW" "$LIB"
	    else
		$SET_DEP_NAME "$LIB_NAME_OLD" "$LIB_NAME_NEW" "$LIB"
	    fi
	done
    done
fi

$CP "$SDL_DIR_BUILD/SDL2/README-SDL.txt" "$LIB_TARGET_DIR"

echo "Done."

exit
